@@ -38,7 +38,7 @@ sub add_task {
 }
 
 sub enqueue {
-    return shift->minion->enqueue( $_[1] );
+    return shift->minion->enqueue( @_ );
 }
 
 1;
@@ -55,7 +55,7 @@ Dancer2::Plugin::Minion - Use the Minion job queue in your Dancer2 apps.
 
 =head1 VERSION
 
-version 0.2.0
+version 0.2.1
 
 =head1 SYNOPSIS
 
